#!/bin/sh
#----------------------------------------------------------------------------
# /var/install/config.d/capi-update.sh - parameter update script
#
# Creation:     2005-12-01 hb
# Last Update:  $Id: capi-update.sh 108085 2023-12-06 16:34:23Z hbfl $
#
# Copyright (c) 2005-2024 Holger Bruenjes <holgerbruenjes(at)gmx(dot)net>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#----------------------------------------------------------------------------

# set packages name
package_name=capi

# include configlib for using printvar
. /var/install/include/configlib

VERSION=3.4.1

# ---------------------------------------------------------------------------
# Set the default values for configuration
# ---------------------------------------------------------------------------
get_defaults()
{
#    VERSION=$(sed -n '/<version>/ s# ##g; s#</*version>##gp' \
#              /var/install/packages/${package_name})

# no value available with running install.sh :-(
#    VERSION=$(eisman query --installed --fields='version' ${package_name} |
#                     sed '/-------/d' |
#                     awk '{print $2}')

    START_CAPI='no'

#    CAPI_USE_PASSIVE_CARD='no'
#    CAPI_USE_FRITZ_CLASSIC='no'
#    CAPI_FRITZ_CLASSIC_IRQ='5'
#    CAPI_FRITZ_CLASSIC_IO='0x300'
#    CAPI_USE_FRITZ_PNP='no'
#    CAPI_USE_FRITZ_PCI='no'
#    CAPI_FRITZ_PCI_N='1'
#    CAPI_USE_FRITZ_USB='no'
#    CAPI_USE_FRITZ_USB2='no'
#    CAPI_USE_FRITZ_USB21='no'
#    CAPI_USE_FRITZ_XUSB='no'
#    CAPI_USE_FRITZ_PCMCIA='no'

#    CAPI_USE_DSL_CARD='no'
#    CAPI_USE_FRITZ_DSL='no'
#    CAPI_USE_FRITZ_DSL2='no'
#    CAPI_USE_FRITZ_DSL_SL='no'
#    CAPI_USE_FRITZ_USB_DSL='no'
#    CAPI_USE_FRITZ_USB_DSL2='no'
#    CAPI_USE_FRITZ_USB_DSL_SL='no'

#    CAPI_USE_ACTIVE_CARD='no'
#    CAPI_USE_B1='no'
#    CAPI_USE_B1_ISA='no'
#    CAPI_B1_ISA_N='1'
#    CAPI_B1_ISA_1_IRQ='5'
#    CAPI_BI_ISA_1_IO='0x300'
#    CAPI_B1_ISA_1_OPTION='no'
#    CAPI_USE_B1_PCI='no'
#    CAPI_B1_PCI_N='1'
#    CAPI_B1_PCI_1_OPTION='no'
#    CAPI_USE_B1_PCMCIA='no'
#    CAPI_B1_PCMCIA_N='1'
#    CAPI_B1_PCMCIA_1_OPTION='no'
#    CAPI_USE_C2='no'
#    CAPI_C2_N='1'
#    CAPI_C2_1_OPTION_1='no'
#    CAPI_C2_1_OPTION_2='no'
#    CAPI_USE_C4='no'
#    CAPI_C4_N='1'
#    CAPI_C4_1_OPTION_1='no'
#    CAPI_C4_1_OPTION_2='no'
#    CAPI_C4_1_OPTION_3='no'
#    CAPI_C4_1_OPTION_4='no'

    CAPI_USE_REMOTE_CARD='no'
    CAPI_REMOTE_DRIVER='fritzbox'
    CAPI_REMOTE_HOST=''
    CAPI_REMOTE_PORT='5031'
}

# ---------------------------------------------------------------------------
# read old configuration and rename old variables
# ---------------------------------------------------------------------------
rename_old_variables()
{
    # read old values
    if [ -f /etc/config.d/${package_name} ]
    then
        /var/install/bin/backup-file --quiet ${package_name}
        . /etc/config.d/${package_name}

    fi
}

# ---------------------------------------------------------------------------
# Write config and default files
# ---------------------------------------------------------------------------
make_config_file()
{
    internal_conf_file=${1}
    {
    # -----------------------------------------------------------------------
    printgpl --conf ${package_name} '2005-12-01' 'hb' 'Holger Bruenjes, holgerbruenjes(at)gmx(dot)net'
    # -----------------------------------------------------------------------
    echo "# CAPI-VERSION ${VERSION}"
    # -----------------------------------------------------------------------
    printgroup  'General settings'
    # -----------------------------------------------------------------------

    printvar 'START_CAPI'
    printcomment                'Start Capi Server'

#    # -----------------------------------------------------------------------
#    printgroup 'Passive card settings'
#    # -----------------------------------------------------------------------
#
#    # 1.1.0
#    if [ -n "${CAPI_CARD_1_NAME}" ]
#    then
#        case ${CAPI_CARD_1_NAME} in
#        fcclassic)
#            CAPI_USE_FRITZ_CLASSIC='yes'
#            CAPI_USE_PASSIVE_CARD='yes'
#            ;;
#        fcpnp)
#            CAPI_USE_FRITZ_PNP='yes'
#            CAPI_USE_PASSIVE_CARD='yes'
#            ;;
#        fcpci)
#            CAPI_USE_FRITZ_PCI='yes'
#            CAPI_USE_PASSIVE_CARD='yes'
#            ;;
#        fcusb)
#            CAPI_USE_FRITZ_USB='yes'
#            CAPI_USE_PASSIVE_CARD='yes'
#            ;;
#        fcusb2)
#            CAPI_USE_FRITZ_USB='yes'
#            CAPI_USE_PASSIVE_CARD='yes'
#            ;;
#        fxusb)
#            CAPI_USE_FRITZ_XUSB='yes'
#            CAPI_USE_PASSIVE_CARD='yes'
#            ;;
#        b1isa)
#            CAPI_USE_B1_ISA='yes'
#            CAPI_USE_ACTIVE_CARD='yes'
#            ;;
#        b1pci)
#            CAPI_USE_B1_PCI='yes'
#            CAPI_USE_ACTIVE_CARD='yes'
#            ;;
#        *)
#                :
#            ;;
#        esac
#    fi
#     # 1.1.0
#    if [ -n "${CAPI_CARD_1_IRQ}" ]
#    then
#        CAPI_FRITZ_CLASSIC_IRQ=${CAPI_CARD_1_IRQ}
#    fi
#    # 1.1.0
#    if [ -n "${CAPI_CARD_1_IO}" ]
#    then
#        CAPI_FRITZ_CLASSIC_IO=${CAPI_CARD_1_IO}
#    fi
#
#    printvar 'CAPI_USE_PASSIVE_CARD'
#    printcomment                    'Use: yes or no'
#
#    printvar 'CAPI_USE_FRITZ_CLASSIC'
#    printcomment                    'Use: yes or no'
#
#    printvar 'CAPI_FRITZ_CLASSIC_IRQ'
#    printcomment                    '5'
#
#    printvar 'CAPI_FRITZ_CLASSIC_IO'
#    printcomment                    '0x300'
#
#    printvar 'CAPI_USE_FRITZ_PNP'
#    printcomment                    'Use: yes or no'
#
#    printvar 'CAPI_USE_FRITZ_PCI'
#    printcomment                    'Use: yes or no'
#
#    # 1.9.0
#    if [ "${CAPI_USE_FRITZ_PCI}"  = "yes" ]
#    then
#        if [ -z "${CAPI_FRITZ_PCI_N}" ]
#        then
#            CAPI_FRITZ_PCI_N=1
#        fi
#    fi
#    printvar 'CAPI_FRITZ_PCI_N'
#    printcomment                    'Number of PCI Cards'
#
#    printvar 'CAPI_USE_FRITZ_USB'
#    printcomment                    'Use: yes or no'
#
#    printvar 'CAPI_USE_FRITZ_USB2'
#    printcomment                    'Use: yes or no'
#
#    printvar 'CAPI_USE_FRITZ_USB21'
#    printcomment                    'Use: yes or no'
#
#    printvar 'CAPI_USE_FRITZ_XUSB'
#    printcomment                    'Use: yes or no'
#
#    printvar 'CAPI_USE_FRITZ_PCMCIA'
#    printcomment                    'Use: yes or no, also for A1 Card PCMCIA'
#
#    # -----------------------------------------------------------------------
#    printgroup 'DSL card settings     only for ISDN use'
#    # -----------------------------------------------------------------------
#
#    printvar 'CAPI_USE_DSL_CARD'
#    printcomment                    'Use: yes or no'
#
#    printvar 'CAPI_USE_FRITZ_DSL'
#    printcomment                    'Use: yes or no'
#
#    printvar 'CAPI_USE_FRITZ_DSL2'
#    printcomment                    'Use: yes or no'
#
#    printvar 'CAPI_USE_FRITZ_DSL_SL'
#    printcomment                    'Use: yes or no'
#
#    printvar 'CAPI_USE_FRITZ_USB_DSL'
#    printcomment                    'Use: yes or no'
#
#    printvar 'CAPI_USE_FRITZ_USB_DSL2'
#    printcomment                    'Use: yes or no'
#
#    printvar 'CAPI_USE_FRITZ_USB_DSL_SL'
#    printcomment                    'Use: yes or no'
#
#    # -----------------------------------------------------------------------
#    printgroup 'Actice card settings'
#    # -----------------------------------------------------------------------
#
#    printvar 'CAPI_USE_ACTIVE_CARD'
#    printcomment                    'Use: yes or no'
#
#    printvar 'CAPI_USE_B1'
#    printcomment                    'Use: yes or no'
#
#    printvar 'CAPI_USE_B1_ISA'
#    printcomment                    'Use: yes or no'
#
#    # 1.3.0
#    if [ ${CAPI_B1_ISA_N} -eq 0 ]
#    then
#        CAPI_B1_ISA_N="1"
#    fi
#
#    printvar 'CAPI_B1_ISA_N'
#    printcomment                    'Number of B1 ISA Cards'
#
#    capi_idx=1
#    while [ "${capi_idx}" -le "${CAPI_B1_ISA_N}" ]
#    do
#        # 1.1.3
#        if [ -n "${CAPI_CARD_1_IRQ}" ]
#        then
#            CAPI_B1_ISA_${capi_idx}_IRQ=${CAPI_CARD_1_IRQ}
#        fi
#        # 1.1.3
#        if [ -n "${CAPI_CARD_1_IO}" ]
#        then
#            CAPI_B1_ISA_${capi_idx}_IO=${CAPI_CARD_1_IO}
#        fi
#
#        printvar "CAPI_B1_ISA_${capi_idx}_IRQ"
#        printcomment                  '5'
#
#        printvar "CAPI_B1_ISA_${capi_idx}_IO"
#        printcomment                  '0x300'
#
#        printvar "CAPI_B1_ISA_${capi_idx}_OPTION"
#        printcomment                  'Use: yes for P2P, no for emty'
#
#        capi_idx=$((${capi_idx} + 1))
#    done
#
#
#    printvar 'CAPI_USE_B1_PCI'
#    printcomment                    'Use: yes or no'
#
#    # 1.3.0
#    if [ ${CAPI_B1_PCI_N} -eq 0 ]
#    then
#        CAPI_B1_PCI_N="1"
#    fi
#
#    printvar 'CAPI_B1_PCI_N'
#    printcomment                    'Number of B1 PCI Cards'
#
#    capi_idx=1
#    while [ "${capi_idx}" -le "${CAPI_B1_PCI_N}" ]
#    do
#        printvar "CAPI_B1_PCI_${capi_idx}_OPTION"
#        printcomment                'Use: yes for P2P, no for emty'
#
#        capi_idx=$((${capi_idx} + 1))
#    done
#
#
#    printvar 'CAPI_USE_B1_PCMCIA'
#    printcomment                    'Use: yes or no, also for M2 ISDN Card'
#
#    printvar 'CAPI_B1_PCMCIA_N'
#    printcomment                    'Number of B1 PCI Cards'
#
#    capi_idx=1
#    while [ "${capi_idx}" -le "${CAPI_B1_PCMCIA_N}" ]
#    do
#        printvar "CAPI_B1_PCMCIA_${capi_idx}_OPTION"
#        printcomment                'Use: yes for P2P, no for empty'
#
#        capi_idx=$((${capi_idx} + 1))
#    done
#
#
#    printvar 'CAPI_USE_C2'
#    printcomment                    'Use: yes or no'
#
#    # 1.3.0
#    if [ ${CAPI_C2_N} -eq 0 ]
#    then
#        CAPI_C2_N="1"
#    fi
#
#    printvar 'CAPI_C2_N'
#    printcomment                    'Number of C2 Cards'
#
#    capi_idx=1
#    while [ "${capi_idx}" -le "${CAPI_C2_N}" ]
#    do
#        printvar "CAPI_C2_${capi_idx}_OPTION_1"
#        printcomment                'Use: yes for P2P, no for emty'
#
#        printvar "CAPI_C2_${capi_idx}_OPTION_2"
#        printcomment                'Use: yes for P2P, no for emty'
#
#        capi_idx=$((${capi_idx} + 1))
#    done
#
#
#    printvar 'CAPI_USE_C4'
#    printcomment                    'Use: yes or no'
#
#    # 1.3.0
#    if [ ${CAPI_C4_N} -eq 0 ]
#    then
#        CAPI_C4_N="1"
#    fi
#
#    printvar 'CAPI_C4_N'
#    printcomment                    'Number of C4 Cards'
#
#    capi_idx=1
#    while [ "${capi_idx}" -le "${CAPI_C4_N}" ]
#    do
#        printvar "CAPI_C4_${capi_idx}_OPTION_1"
#        printcomment                'Use: yes for P2P, no for emty'
#
#        printvar "CAPI_C4_${capi_idx}_OPTION_2"
#        printcomment                'Use: yes for P2P, no for emty'
#
#        printvar "CAPI_C4_${capi_idx}_OPTION_3"
#        printcomment                'Use: yes for P2P, no for emty'
#
#        printvar "CAPI_C4_${capi_idx}_OPTION_4"
#        printcomment                'Use: yes for P2P, no for emty'
#
#        capi_idx=$((${capi_idx} + 1))
#    done

    # -----------------------------------------------------------------------
    printgroup 'Remote CAPI via FRITZ!Box etc...'
    # -----------------------------------------------------------------------

    printvar 'CAPI_USE_REMOTE_CARD'
    printcomment                    'Use: yes or no'

    printvar 'CAPI_REMOTE_DRIVER'
    printcomment                    'fritzbox or rcapi'

    printvar 'CAPI_REMOTE_HOST'
    printcomment                    'Hostname or ip-address'

    printvar 'CAPI_REMOTE_PORT'
    printcomment                    'Portnumber, default 5031'

    # -----------------------------------------------------------------------
    printend
    # -----------------------------------------------------------------------

    } > ${internal_conf_file}
    # Set rights
    chmod 0600 ${internal_conf_file}
    chown root ${internal_conf_file}
}

# ---------------------------------------------------------------------------
# Create the check.d file
# ---------------------------------------------------------------------------
make_check_file()
{
printgpl --check ${package_name} '2005-12-01' 'hb' >/etc/check.d/${package_name}
cat >>/etc/check.d/${package_name} <<EOF
# Variable                 OPT_VARIABLE             VARIABLE_N        VALUE

START_CAPI                 -                        -                 YESNO
#CAPI_USE_PASSIVE_CARD      START_CAPI               -                 YESNO
#CAPI_USE_FRITZ_CLASSIC     CAPI_USE_PASSIVE_CARD    -                 YESNO
#CAPI_FRITZ_CLASSIC_IRQ     CAPI_USE_FRITZ_CLASSIC   -                 NUMERIC
#CAPI_FRITZ_CLASSIC_IO      CAPI_USE_FRITZ_CLASSIC   -                 CAPI_CARD_IO_CUI
#CAPI_USE_FRITZ_PNP         CAPI_USE_PASSIVE_CARD    -                 YESNO
#CAPI_USE_FRITZ_PCI         CAPI_USE_PASSIVE_CARD    -                 YESNO
#CAPI_FRITZ_PCI_N           CAPI_USE_FRITZ_PCI       -                 NUM_CAPI_ANZ
#CAPI_USE_FRITZ_USB         CAPI_USE_PASSIVE_CARD    -                 YESNO
#CAPI_USE_FRITZ_USB2        CAPI_USE_PASSIVE_CARD    -                 YESNO
#CAPI_USE_FRITZ_USB21       CAPI_USE_PASSIVE_CARD    -                 YESNO
#CAPI_USE_FRITZ_XUSB        CAPI_USE_PASSIVE_CARD    -                 YESNO
#CAPI_USE_FRITZ_PCMCIA      CAPI_USE_PASSIVE_CARD    -                 YESNO
#
#CAPI_USE_DSL_CARD          START_CAPI               -                 YESNO
#CAPI_USE_FRITZ_DSL         CAPI_USE_DSL_CARD        -                 YESNO
#CAPI_USE_FRITZ_DSL2        CAPI_USE_DSL_CARD        -                 YESNO
#CAPI_USE_FRITZ_DSL_SL      CAPI_USE_DSL_CARD        -                 YESNO
#CAPI_USE_FRITZ_USB_DSL     CAPI_USE_DSL_CARD        -                 YESNO
#CAPI_USE_FRITZ_USB_DSL2    CAPI_USE_DSL_CARD        -                 YESNO
#CAPI_USE_FRITZ_USB_DSL_SL  CAPI_USE_DSL_CARD        -                 YESNO
#
#CAPI_USE_ACTIVE_CARD       START_CAPI               -                 YESNO
#CAPI_USE_B1                CAPI_USE_ACTIVE_CARD     -                 YESNO
#CAPI_USE_B1_ISA            CAPI_USE_B1              -                 YESNO
#CAPI_B1_ISA_N              CAPI_USE_B1_ISA          -                 NUM_CAPI_ANZ
#CAPI_B1_ISA_%_IRQ          CAPI_USE_B1_ISA          CAPI_B1_ISA_N     NUMERIC
#CAPI_B1_ISA_%_IO           CAPI_USE_B1_ISA          CAPI_B1_ISA_N     CAPI_CARD_IO_CUI
#CAPI_B1_ISA_%_OPTION       CAPI_USE_B1_ISA          CAPI_B1_ISA_N     YESNO
#CAPI_USE_B1_PCI            CAPI_USE_B1              -                 YESNO
#CAPI_B1_PCI_N              CAPI_USE_B1_PCI          -                 NUM_CAPI_ANZ
#CAPI_B1_PCI_%_OPTION       CAPI_USE_B1_PCI          CAPI_B1_PCI_N     YESNO
#CAPI_USE_B1_PCMCIA         CAPI_USE_B1              -                 YESNO
#CAPI_B1_PCMCIA_N           CAPI_USE_B1_PCMCIA       -                 NUM_CAPI_ANZ
#CAPI_B1_PCMCIA_%_OPTION    CAPI_USE_B1_PCMCIA       CAPI_B1_PCMCIA_N  YESNO
#CAPI_USE_C2                CAPI_USE_ACTIVE_CARD     -                 YESNO
#CAPI_C2_N                  CAPI_USE_C2              -                 NUM_CAPI_ANZ
#CAPI_C2_%_OPTION_1         CAPI_USE_C2              CAPI_C2_N         YESNO
#CAPI_C2_%_OPTION_2         CAPI_USE_C2              CAPI_C2_N         YESNO
#CAPI_USE_C4                CAPI_USE_ACTIVE_CARD     -                 YESNO
#CAPI_C4_N                  CAPI_USE_C4              -                 NUM_CAPI_ANZ
#CAPI_C4_%_OPTION_1         CAPI_USE_C4              CAPI_C4_N         YESNO
#CAPI_C4_%_OPTION_2         CAPI_USE_C4              CAPI_C4_N         YESNO
#CAPI_C4_%_OPTION_3         CAPI_USE_C4              CAPI_C4_N         YESNO
#CAPI_C4_%_OPTION_4         CAPI_USE_C4              CAPI_C4_N         YESNO

CAPI_USE_REMOTE_CARD       START_CAPI               -                 YESNO
CAPI_REMOTE_DRIVER         CAPI_USE_REMOTE_CARD     -                 CAPI_REMOTE_DRV_CUI
CAPI_REMOTE_HOST           CAPI_USE_REMOTE_CARD     -                 NONE
CAPI_REMOTE_PORT           CAPI_USE_REMOTE_CARD     -                 NUMERIC
EOF

    # Set rights for check.d file
    chmod 0600 /etc/check.d/${package_name}
    chown root /etc/check.d/${package_name}


printgpl --check_exp ${package_name} '2005-12-01' 'hb'  >/etc/check.d/${package_name}.exp
cat >>/etc/check.d/${package_name}.exp <<EOF
#CAPI_CARD_IO_CUI   = '0x200|0x240|0x300|0x340'
#                            : 'Use IO Adress z.B 0x300 etc'
#NUM_CAPI_ANZ                = '[0-4]'
#                            : 'Maximal 4 Cards'
CAPI_REMOTE_DRV_CUI         = 'fritzbox|rcapi'
                            : 'Use only fritzbox or rcapi'
EOF

    # Set rights for check.exp file
    chmod 0600 /etc/check.d/${package_name}.exp
    chown root /etc/check.d/${package_name}.exp

#printgpl --check_ext ${package_name} '2005-12-01' 'hb'  >/etc/check.d/${package_name}.ext
#cat >>/etc/check.d/${package_name}.ext <<EOF
#
#set scount=0
#if ( capi_use_passive_card == "yes" )
#then
#    set scount=scount+1
#fi
#
#if (capi_use_active_card == "yes" )
#then
#    set scount=scount+1
#fi
#if (capi_use_remote_card == "yes" )
#then
#    set scount=scount+1
#fi
#if (scount > "1")
#then
#    error "The CAPI can only use passive or active or remote card! Use only one of this."
#fi
#
#if (capi_use_passive_card)
#then
#set pcount=0
#    if (capi_use_fritz_classic)
#    then
#    set pcount=pcount+1
#    fi
#
#    if (capi_use_fritz_pnp)
#    then
#    set pcount=pcount+1
#    fi
#
#    if (capi_use_fritz_pci)
#    then
#    set pcount=pcount+1
#    fi
#
#    if (capi_use_fritz_usb)
#    then
#    set pcount=pcount+1
#    fi
#
#    if (capi_use_fritz_usb2)
#    then
#    set pcount=pcount+1
#    fi
#
#    if (capi_use_fritz_usb21)
#    then
#    set pcount=pcount+1
#    fi
#
#    if (capi_use_fritz_xusb)
#    then
#    set pcount=pcount+1
#    fi
#
#    if (capi_use_fritz_pcmcia)
#    then
#    set pcount=pcount+1
#    fi
#
#    if (pcount > "1")
#    then
#        error "You can not use more than 1 passive card!"
#    fi
#fi
#
#if (capi_use_active_card)
#then
#set acount=0
#    if (capi_use_b1_isa)
#    then
#    set acount=acount+capi_b1_isa_n
#    fi
#
#    if (capi_use_b1_pci)
#    then
#    set acount=acount+capi_b1_pci_n
#    fi
#
#    if (capi_use_b1_pcmcia)
#    then
#    set acount=acount+capi_b1_pcmcia_n
#    fi
#
#    if (capi_use_c2)
#    then
#    set acount=acount+capi_c2_n
#    fi
#
#    if (capi_use_c4)
#    then
#    set acount=acount+capi_c4_n
#    fi
#
#    if (acount > "4")
#    then
#        error "\$acount - You can not use more than 4 active cards!"
#    fi
#fi
#EOF
#
#    # Set rights for check.ext file
#    chmod 0600 /etc/check.d/${package_name}.ext
#    chown root /etc/check.d/${package_name}.ext
}

# ---------------------------------------------------------------------------
# main
# ---------------------------------------------------------------------------
main()
{
    get_defaults

    # write default config file
    make_config_file /etc/default.d/${package_name}

    # update from old version
    rename_old_variables

    # write new config file
    make_config_file /etc/config.d/${package_name}

    # write check.d file
    make_check_file

    exit 0
}

# ---------------------------------------------------------------------------
# exec main
# ---------------------------------------------------------------------------
main "${@}"

# ---------------------------------------------------------------------------
# end
# ---------------------------------------------------------------------------
