#!/bin/sh
#----------------------------------------------------------------------------
# /var/install/config.d/capi.sh - configuration generator script for Capi
#
# Creation:     2002-02-26  jed
# Last Update:  $Id: capi.sh 109845 2024-03-18 10:39:59Z hbfl $
#
# Copyright (c) 2002-2005 Fabian Wolter
# Copyright (c) 2005-2024 Holger Bruenjes, holgerbruenjes(at)gmx(dot)net
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#----------------------------------------------------------------------------

. /var/install/include/eislib

# set package name
package_name=capi

#debug=true

if ${debug:-false}
then
    exec 2>/tmp/$(basename ${0})-trace$$.log
    set -x
    ask_debug=true
    export ask_debug
fi

config_file=/etc/config.d/capi
gen_file=/etc/isdn/capi.conf
capi20_file=/etc/isdn/capi20.conf

VERSION=3.4.1

capi_version=${VERSION}

firmware_version=1.0.0
pcmcia_version=0.9.0

# ---------------------------------------------------------------------------
# config Dateien
# ---------------------------------------------------------------------------
. ${config_file}

start_capi=true
pcmcia_capi=false
capi_header=false
line_header=false
capi_uname=$(echo $(uname -r) | tr [[:upper:]] [[:lower:]])
# ---------------------------------------------------------------------------
# capi start
# ---------------------------------------------------------------------------
capi_start()
{
    if /usr/sbin/service is-enabled ${package_name}.service
    then
        /usr/sbin/service daemon-reload
    else  
        /usr/sbin/service enable ${package_name}.service
    fi
}

# ---------------------------------------------------------------------------
# capi stop
# ---------------------------------------------------------------------------
capi_stop()
{
    /usr/sbin/service disable ${package_name}.service     
}


# ---------------------------------------------------------------------------
#   remove  ...etc/config
# ---------------------------------------------------------------------------
remove_config()
{
    echo 'TRACELEVEL 0' > ${capi20_file}
    echo "dummy" >  ${gen_file}
}

# ---------------------------------------------------------------------------
#   create  ...etc/config
# ---------------------------------------------------------------------------
create_config()
{
    # first check if capi running
    _capi_status="$(cat /proc/capi/controller 2>/dev/null)"

    if [ -n "${_capi_status}" ]
    then
        /usr/sbin/service --quiet stop capi 
    fi

    # create empty conf files ;-)
  #  rm -f ${gen_file}
    >  ${gen_file}
    #    rm -f ${capi20_file}
    {
        echo 'TRACELEVEL 0'
    } > ${capi20_file}

    capi_card=''
    capi_file='-'
    capi_proto='DSS1'
    capi_io='-'
    capi_irq='-'
    capi_mem='-'
    capi_cardnr='-'
    capi_options=''

#    if [ "${CAPI_USE_PASSIVE_CARD}" = "yes" ]
#    then
#        if [ "${CAPI_USE_FRITZ_CLASSIC}" = "yes" ]
#        then
#            check_package "avm_fritz_classic_${capi_uname}" 'CAPI_USE_FRITZ_CLASSIC'
#            retvar=${?}
#            if [ ${retvar} -eq 0 ]
#            then
#                capi_card='fcclassic'
#                capi_io="${CAPI_FRITZ_CLASSIC_IO}"
#                capi_irq="${CAPI_FRITZ_CLASSIC_IRQ}"
#                print_line
#                capi_io='-'
#                capi_irq='-'
#            fi
#            change_menu non-usb
#        elif [ "${CAPI_USE_FRITZ_PNP}" = "yes" ]
#        then
#            check_package "avm_fritz_pnp_${capi_uname}" 'CAPI_USE_FRITZ_PNP'
#            retvar=${?}
#            if [ ${retvar} -eq 0 ]
#            then
#                capi_card='fcpnp'
#                print_line
#            fi
#            change_menu non-usb
#        elif [ "${CAPI_USE_FRITZ_PCI}" = "yes" ]
#        then
#            capi_idx=1
#            while [ ${capi_idx} -le ${CAPI_FRITZ_PCI_N} ]
#            do
#                case ${capi_idx} in
#                1)
#                    case ${capi_uname} in
#                    2.6.32*|3.*|4.*)
#                        check_package "avm_fritz-${capi_idx}_pci_${capi_uname}" 'CAPI_USE_FRITZ_PCI'
#                        retvar=${?}
#                        if [ ${retvar} -eq 0 ]
#                        then
#                            capi_card="f${capi_idx}pci"
#                            print_line
#                        fi
#                        ;;
#                    *)
#                        check_package "avm_fritz_pci_${capi_uname}" 'CAPI_USE_FRITZ_PCI'
#                        retvar=${?}
#                        if [ ${retvar} -eq 0 ]
#                        then
#                            capi_card='fcpci'
#                            print_line
#                        fi
#                        ;;
#                    esac
#                    ;;
#                *)
#                    check_package "avm_fritz-${capi_idx}_pci_${capi_uname}" 'CAPI_USE_FRITZ_PCI'
#                    retvar=${?}
#                    if [ ${retvar} -eq 0 ]
#                    then
#                        capi_card="f${capi_idx}pci"
#                        print_line
#                    fi
#                    ;;
#                esac
#                capi_idx=$((${capi_idx} + 1))
#            done
#            change_menu non-usb
#        elif [ "${CAPI_USE_FRITZ_USB}" = "yes" ]
#        then
#            check_package "avm_fritz_usb_${capi_uname}" 'CAPI_USE_FRITZ_USB'
#            retvar=${?}
#            if [ ${retvar} -eq 0 ]
#            then
#                capi_card='fcusb'
#                print_line
#            fi
#            change_menu usb
#        elif [ "${CAPI_USE_FRITZ_USB2}" = "yes" ]
#        then
#            check_package "avm_fritz_usb2x_${capi_uname}" 'CAPI_USE_FRITZ_USB2'
#            retvar=${?}
#            if [ ${retvar} -eq 0 ]
#            then
#                check_firmware 'avm_fritz_usb2-firmware' 'CAPI_USE_FRITZ_USB2'
#                retvar=${?}
#            fi
#
#            if [ ${retvar} -eq 0 ]
#            then
#                capi_card='fcusb2'
#                capi_file='fus2base.frm'
#                print_line
#            fi
#            change_menu usb
#        elif [ "${CAPI_USE_FRITZ_USB21}" = "yes" ]
#        then
#            check_package "avm_fritz_usb2x_${capi_uname}" 'CAPI_USE_FRITZ_USB21'
#            retvar=${?}
#            if [ ${retvar} -eq 0 ]
#            then
#                check_firmware "avm_fritz_usb21-firmware" 'CAPI_USE_FRITZ_USB21'
#                retvar=${?}
#            fi
#            if [ ${retvar} -eq 0 ]
#            then
#                capi_card='fcusb2'
#                capi_file='fus3base.frm'
#                print_line
#            fi
#            change_menu usb
#        elif [ "${CAPI_USE_FRITZ_XUSB}" = "yes" ]
#        then
#            check_package "avm_fritz_xusb_${capi_uname}" 'CAPI_USE_FRITZ_XUSB'
#            retvar=${?}
#            if [ ${retvar} -eq 0 ]
#            then
#                capi_card='fxusb'
#                print_line
#            fi
#            change_menu usb
#        elif [ "${CAPI_USE_FRITZ_PCMCIA}" = "yes" ]
#        then
#            check_package "avm_fritz_pcmcia_${capi_uname}" 'CAPI_USE_FRITZ_PCMCIA'
#            retvar=${?}
#            if [ ${retvar} -eq 0 ]
#            then
#  #             if [ -f /etc/pcmcia/isdn.opts ]
#  #             then
#                #    sed -e 's/^\(P2P\)=.*/\1=no/' /etc/pcmcia/isdn.opts >/tmp/isdn-opts.$$
#                #    cp /tmp/isdn-opts.$$ /etc/pcmcia/isdn.opts
#                #    rm -f /tmp/isdn-opts.$$
#
#                    capi_card='fcpcmcia'
#                    print_line
#
#                    pcmcia_capi=true
#    #            else
#     #               echo
#      #              mecho --warn " - isdn.opts is missing, please install 'pcmcia' again"
#       #             echo
#        #            anykey
#         #           exit 1
#          #      fi
#            fi
#            change_menu non-usb
#        fi
#    # end ${CAPI_USE_PASSIVE_CARD}
#    elif [ "${CAPI_USE_ACTIVE_CARD}" = "yes" ]
#    then
#        if [ "${CAPI_USE_C4}" = "yes" ]
#        then
#            check_firmware 'avm_c4-firmware' 'CAPI_USE_C4'
#            retvar=${?}
#            if [ ${retvar} -eq 0 ]
#            then
#                capi_idx=1
#                while [ "${capi_idx}" -le "${CAPI_C4_N}" ]
#                do
#                    capi_card='c4'
#                    capi_file='c4.bin'
#
#                    for options in 1 2 3 4
#                    do
#                        eval c4option='${CAPI_C4_'${capi_idx}'_OPTION_'${options}'}'
#                        if [ "${c4option}" = "yes" ]
#                        then
#                            capi_options='P2P'
#                        fi
#                        print_line
#                    done
#                capi_idx=$((${capi_idx} + 1))
#                done
#            fi
#            change_menu non-usb
#        # end ${CAPI_USE_C4}
#        fi
#
#        if [ "${CAPI_USE_C2}" = "yes" ]
#        then
#            check_firmware 'avm_c2-firmware' 'CAPI_USE_C2'
#            retvar=${?}
#            if [ ${retvar} -eq 0 ]
#            then
#                capi_idx=1
#                while [ "${capi_idx}" -le "${CAPI_C2_N}" ]
#                do
#                    capi_card='c2'
#                    capi_file='c2.bin'
#
#                    for options in 1 2
#                    do
#                        eval c2option='${CAPI_C2_'${capi_idx}'_OPTION_'${options}'}'
#                        if [ "${c2option}" = "yes" ]
#                        then
#                            capi_options='P2P'
#                        fi
#                        print_line
#                    done
#                capi_idx=$((${capi_idx} + 1))
#                done
#            fi
#            change_menu non-usb
#        # end ${CAPI_USE_C2}
#        fi
#
#        if [ "${CAPI_USE_B1}" = "yes" ]
#        then
#            if [ "${CAPI_USE_B1_PCI}" = "yes" ]
#            then
#                check_firmware 'avm_b1-firmware' 'CAPI_USE_B1'
#                retvar=${?}
#                if [ ${retvar} -eq 0 ]
#                then
#
#                    capi_idx=1
#                    while [ "${capi_idx}" -le "${CAPI_B1_PCI_N}" ]
#                    do
#                        eval pcioption='${CAPI_B1_PCI_'${capi_idx}'_OPTION}'
#
#                        capi_card='b1pci'
#                        capi_file='b1.t4'
#
#                        if [ "${pcioption}" = "yes" ]
#                        then
#                            capi_options='P2P'
#                        fi
#                        print_line
#
#                    capi_idx=$((${capi_idx} + 1))
#                    done
#                fi
#            fi
#
#            if [ "${CAPI_USE_B1_ISA}" = "yes" ]
#            then
#                check_firmware 'avm_b1_firmware' 'CAPI_USE_B1'
#                retvar=${?}
#                if [ ${retvar} -eq 0 ]
#                then
#                    capi_idx=1
#                    while [ "${capi_idx}" -le "${CAPI_B1_ISA_N}" ]
#                    do
#                        eval isaoption='${CAPI_B1_ISA_'${capi_idx}'_OPTION}'
#                        eval irq='${CAPI_B1_ISA_'${capi_idx}'_IRQ}'
#                        eval io='${CAPI_B1_ISA_'${capi_idx}'_IO}'
#
#                        capi_card='b1isa'
#                        capi_file='b1.t4'
#                        capi_io="${io}"
#                        capi_irq="${irq}"
#
#                        if [ "${isaoption}" = "yes" ]
#                        then
#                            capi_options='P2P'
#                        fi
#                        print_line
#                        capi_io='-'
#                        capi_irq='-'
#
#                    capi_idx=$((${capi_idx} + 1))
#                    done
#                fi
#            fi
#
#            if [ "${CAPI_USE_B1_PCMCIA}" = "yes" ]
#            then
#                check_firmware 'avm_b1pcmcia-firmware' 'CAPI_USE_B1_PCMCIA'
#                retvar=${?}
#                if [ ${retvar} -eq 0 ]
#                then
#              #      if [ -f /etc/pcmcia/isdn.opts ]
#              #      then
#                        capi_idx=1
#                        while [ "${capi_idx}" -le "${CAPI_B1_PCMCIA_N}" ]
#                        do
#                            eval pcioption='${CAPI_B1_PCMCIA_'${capi_idx}'_OPTION}'
#
#                            if [ "${pcioption}" = "yes" ]
#                            then
#                          #      capi_card="b1pcmcia"
#                          #      capi_file="b1.t4"
#                                capi_options='P2P'
#                          #      print_line
#                         #       sed -e 's/^\(P2P\)=.*/\1=yes/' /etc/pcmcia/isdn.opts >/tmp/isdn-opts.$$
#                         #       cp /tmp/isdn-opts.$$ /etc/pcmcia/isdn.opts
#                         #       rm -f /tmp/isdn-opts.$$
#                           # else
#                           fi
#                                capi_card='b1pcmcia'
#                                capi_file='b1.t4'
#                                print_line
#                        #      sed -e 's/^\(P2P\)=.*/\1=no/' /etc/pcmcia/isdn.opts >/tmp/isdn-opts.$$
#                        #        cp /tmp/isdn-opts.$$ /etc/pcmcia/isdn.opts
#                        #        rm -f /tmp/isdn-opts.$$
#                            #fi
#
#                        capi_idx=$((${capi_idx} + 1))
#                        done
#                        pcmcia_capi=true
#               #     else
#               #         echo
#               #         mecho -warn " - isdn.opts is missing, please install 'pcmcia' again"
#               #         echo
#               #         anykey
#               #         exit 1
#               #     fi
#               fi
#            fi
#            change_menu non-usb
#        # end ${CAPI_USE_B1}
#        fi
#    elif [ "${CAPI_USE_REMOTE_CARD}" = "yes" ]
    if [ "${CAPI_USE_REMOTE_CARD}" = "yes" ]
    then
        {
        echo 'TRACELEVEL 0'
        echo "REMOTE  ${CAPI_REMOTE_DRIVER}  ${CAPI_REMOTE_HOST}  ${CAPI_REMOTE_PORT}"
        } > ${capi20_file}
#        remote_capi=true
        # end ${CAPI_USE_+++_CARD}
#        change_menu non-usb
    fi
#
#    if [ "${CAPI_USE_DSL_CARD}" = "yes" ]
#    then
#        if [ "${CAPI_USE_FRITZ_DSL}" = "yes" ]
#        then
#            check_package "avm_fritz_dsl_${capi_uname}" 'CAPI_USE_FRITZ_DSL'
#            retvar=${?}
#            if [ ${retvar} -eq 0 ]
#            then
#                check_firmware 'avm_fritz_dsl-firmware' 'CAPI_USE_FRITZ_DSL'
#                retvar=${?}
#            fi
#            if [ ${retvar} -eq 0 ]
#            then
#                capi_card='fcdsl'
#                capi_file='fdslbase.bin'
#                print_line
#            fi
#            change_menu non-usb
#        fi
#
#        if [ "${CAPI_USE_FRITZ_DSL_SL}" = "yes" ]
#        then
#            check_package "avm_fritz_dslsl_${capi_uname}" 'CAPI_USE_FRITZ_DSL_SL'
#            retvar=${?}
#            if [ ${retvar} -eq 0 ]
#            then
#                capi_card='fcdslsl'
#                capi_file='fdssbase.bin'
#                print_line
#            fi
#            change_menu non-usb
#        fi
#
#        if [ "${CAPI_USE_FRITZ_DSL2}" = "yes" ]
#        then
#            check_package "avm_fritz_dsl2_${capi_uname}" 'CAPI_USE_FRITZ_DSL2'
#            retvar=${?}
#            if [ ${retvar} -eq 0 ]
#            then
#                check_firmware 'avm_fritz_dsl2-firmware' 'CAPI_USE_FRITZ_DSL2'
#                retvar=${?}
#            fi
#            if [ ${retvar} -eq 0 ]
#            then
#                capi_card='fcdsl2'
#                capi_file='fds2base.bin'
#                print_line
#            fi
#            change_menu non-usb
#        fi
#
#        if [ "${CAPI_USE_FRITZ_USB_DSL}" = "yes" ]
#        then
#            check_package "avm_fritz_usbdsl_${capi_uname}" 'CAPI_USE_FRITZ_USB_DSL'
#            retvar=${?}
#            if [ ${retvar} -eq 0 ]
#            then
#                capi_card='fcdslusb'
#                capi_file='fdsubase.frm'
#                print_line
#            fi
#            change_menu usb
#        fi
#
#        if [ "${CAPI_USE_FRITZ_USB_DSL2}" = "yes" ]
#        then
#            check_package "avm_fritz_usbdsl2_${capi_uname}" 'CAPI_USE_FRITZ_USB_DSL2'
#            retvar=${?}
#            if [ ${retvar} -eq 0 ]
#            then
#                capi_card='fcdslusb2'
#                capi_file='fds2base.frm'
#                print_line
#            fi
#            change_menu usb
#        fi
#
#        if [ "${CAPI_USE_FRITZ_USB_DSL_SL}" = "yes" ]
#        then
#            check_package "avm_fritz_usbdslsl_${capi_uname}" 'CAPI_USE_FRITZ_USB_DSL_SL'
#            retvar=${?}
#            if [ ${retvar} -eq 0 ]
#            then
#                capi_card='fcdslslusb'
#                capi_file='fdlubase.frm'
#                print_line
#            fi
#            change_menu usb
#        fi
#
#
#    # end ${CAPI_USE_DSL_CARD}
#    fi

    if [ -f ${gen_file} ]
    then
        chown root:root ${gen_file}
        chmod 0644 ${gen_file}
        # check if old file exists, delete them
        rm -f /etc/capi.conf
    fi

    if [ -f ${capi20_file} ]
    then
        chown root:root ${capi20_file}
        chmod 0644 ${capi20_file}
    fi

#    if "${pcmcia_capi:-false}"
#    then
#        sed -i 's/\(pcmcia_capi\)=.*/\1=true/' /etc/init.d/capi
#
#        pcmcia_installed=$(eisman check pcmcia ${pcmcia_version})
#
#        case ${pcmcia_installed} in
#        new)
#            mecho --warn " Please update the 'pcmcia' package also."
#            echo
#            anykey
#            ;;
#        esac
#    else
#        sed -i 's/\(pcmcia_capi\)=.*/\1=false/' /etc/init.d/capi
#    fi

#    if "${remote_capi:-false}"
#    then
#        sed -i 's/\(remote_capi\)=.*/\1=true/' /etc/init.d/capi
#        start_capi=true
#    else
#        sed -i 's/\(remote_capi\)=.*/\1=false/' /etc/init.d/capi
#    fi

    if ! "${start_capi}"
    then
        set_parameter_no "START_CAPI"
        capi_stop
    fi
}

# ---------------------------------------------------------------------------
# print capi.conf header
# ---------------------------------------------------------------------------
print_capi_header()
{

cat > ${gen_file} <<EOF
#----------------------------------------------------------------------------
# capi.conf - CAPI configuration file generated by ${package_name} version: ${capi_version}
#
# Do not edit this file, edit ${config_file}
# Creation date:  ${EISDATE}  ${EISTIME}
#----------------------------------------------------------------------------
EOF
}

# ---------------------------------------------------------------------------
# print line in capi.conf
# ---------------------------------------------------------------------------
print_line()
{
    capi_file_length=${#capi_file}

    if [ ${capi_file_length} -le 7 ]
    then
        text_len=7
    else
        text_len=$((${capi_file_length} + 1))
    fi

    if ! "${capi_header}"
    then
        print_capi_header
        capi_header=true
    fi

    if ! "${line_header}"
    then
        printf "%-10s %-${text_len}s %-8s %-8s %-8s %-8s %-8s %s \n" "#card" "file" "proto" "io" "irq" "mem" "cardnr" "options" >>${gen_file}
        line_header=true
    fi

    printf "%-10s %-${text_len}s %-8s %-8s %-8s %-8s %-8s %s \n"  ${capi_card} ${capi_file} ${capi_proto} ${capi_io} ${capi_irq} ${capi_mem} ${capi_cardnr} ${capi_options} >>${gen_file}

    capi_file='-'
    capi_options=''
}

# ---------------------------------------------------------------------------
# msg no package installed
# ---------------------------------------------------------------------------
msg_no_package()
{
    echo
    mecho --info "${2}"
    mecho --info "${1}"
    mecho --warn "was not installed and so"
    mecho --warn "not added to the config files."
    mecho --warn "Please solve that first."
    echo

    if ! ${quietmode:-false}
    then
        anykey
    fi
}

# ---------------------------------------------------------------------------
# create dummy packages info file
# ---------------------------------------------------------------------------
create_dummy_file()
{
# the dummy file can use to work with no Module file exits on Pack-Eis
# and the user has installed it from other location

install_date=$(date +%Y-%m-%d)
eisfair_system=$(cat /etc/eisfair-system)
product=AVM

cat >/var/install/packages/${package}  <<EOF
<package>
<name>${package}</name>
<short>${product} dummy for Kernel ${capi_uname} (no GPL)</short>
<version>0.9.0</version>
<date>${install_date}</date>
<system>${eisfair_system}</system>
<author>Holger Bruenjes, holgerbruenjes(at)gmx(dot)net</author>
<status>testing</status>
<section>drivers</section>
<require-package>capi</require-package>
<description>
This is a dummy package info file
for your own risk
</description>
</package>
EOF
}

# ---------------------------------------------------------------------------
# set parameter to no
# ---------------------------------------------------------------------------
set_parameter_no()
{
    # ${1} rewrite Parameter from 'yes' to 'no'
    # set parameter from 'yes' to 'no'
    sed -i "s/^${1}=.*/${1}='no'/" ${config_file}
}

# ---------------------------------------------------------------------------
# check package
# ---------------------------------------------------------------------------
check_package()
{
    local package="${1}"
    local msg_do_now="${2}"
    local para_no="${2}"
    local retvar
    local pk_ret

    local installed=$(eisman check "${package}")

    if [ "${installed}" = "not-installed" ]
    then
        if ${quietmode:-false}
        then
            set_parameter_no "${para_no}"
            msg_no_package "'${msg_do_now}'" "${package}"
            pk_ret=1
        else
            eisman install --auto --unstable "${package}"
            retvar=${?}

            if [ ${retvar:-1} -eq 0 ]
            then
                start_capi=true
                pk_ret=0
            else
                # if no capi modules file installed, generate a dummy file
                echo
                mecho --info "At your own risk, you can install"
                mecho --info "a dummy package-info file"
                echo
                _ask_tmpfile=$(mktemp -t ask.XXXXXXXXXX)
                /var/install/bin/ask "Install" "n" >${_ask_tmpfile}
                rc=${?}
                read a < ${_ask_tmpfile}
                rm -f ${_ask_tmpfile}

                # if ask break, ask returned 255
                if [ ${rc} = 255 ]
                then
                    a=no
                fi

                case ${a} in
                yes)
                    create_dummy_file
                    start_capi=true
                    pk_ret=0
                    ;;
                *)
                    set_parameter_no "${para_no}"
                    msg_no_package "'${msg_do_now}'" "${package}"
                    pk_ret=1
                    ;;
                esac
            fi
        fi
    else
        start_capi=true
        pk_ret=0
    fi

    return ${pk_ret}
}

# ---------------------------------------------------------------------------
# check firmware
# ---------------------------------------------------------------------------
check_firmware()
{
    local package="${1}"
    local msg_do_now="${2}"
    local para_no="${2}"
    local retvar
    local fw_ret

    local installed=$(eisman check 'firmware_avm' "${firmware_version}")

    if [ "${installed}" = "not-installed" ] ||
       [ "${installed}" = "new" ]
    then
        if ${quietmode:-false}
        then
            retvar=1
        else
            eisman install --unstable --auto firmware_avm
            retvar=${?}
        fi
    fi

    if [ ${retvar:-0} -eq 0 ]
    then
        start_capi=true
        fw_ret=0
    else
        set_parameter_no "${para_no}"
        msg_no_package "'${msg_do_now}'" "${package}"
        fw_ret=1
    fi

    return ${fw_ret}
}

# ---------------------------------------------------------------------------
# change menu
# ---------------------------------------------------------------------------
change_menu()
{
    menu_path='/var/install/menu'
    menu_file='setup.system.hardware.capi.server.menu'

    case ${1} in
    usb)
        cp /var/lib/capi/usb-${menu_file} ${menu_path}/${menu_file}
        ;;
    non_usb)
        cp /var/lib/capi/non-usb-${menu_file} ${menu_path}/${menu_file}
        ;;
    esac

    chmod 640 ${menu_path}/${menu_file}
}

# ---------------------------------------------------------------------------
# main
# ---------------------------------------------------------------------------
main()
{
    quietmode=false

    while [ ${#} -gt 0 ]
    do
        case ${1} in
        --quiet)
            quietmode=true
            shift
            ;;
        esac
    done

    case ${START_CAPI} in
    yes)         
        capi_start
        create_config
        ;;
    no)
        capi_stop
        remove_config 
        ;;
    esac

    exit 0
}

# ---------------------------------------------------------------------------
# call function main
# ---------------------------------------------------------------------------
main "${@}"

# ---------------------------------------------------------------------------
# end
# ---------------------------------------------------------------------------
